'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_texture_object'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_texture_object',error_checker=_errors._error_checker)
GL_TEXTURE_1D_BINDING_EXT=_C('GL_TEXTURE_1D_BINDING_EXT',0x8068)
GL_TEXTURE_2D_BINDING_EXT=_C('GL_TEXTURE_2D_BINDING_EXT',0x8069)
GL_TEXTURE_3D_BINDING_EXT=_C('GL_TEXTURE_3D_BINDING_EXT',0x806A)
GL_TEXTURE_PRIORITY_EXT=_C('GL_TEXTURE_PRIORITY_EXT',0x8066)
GL_TEXTURE_RESIDENT_EXT=_C('GL_TEXTURE_RESIDENT_EXT',0x8067)
@_f
@_p.types(_cs.GLboolean,_cs.GLsizei,arrays.GLuintArray,arrays.GLbooleanArray)
def glAreTexturesResidentEXT(n,textures,residences):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBindTextureEXT(target,texture):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteTexturesEXT(n,textures):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenTexturesEXT(n,textures):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsTextureEXT(texture):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray,arrays.GLclampfArray)
def glPrioritizeTexturesEXT(n,textures,priorities):pass
