'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_texture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_texture',error_checker=_errors._error_checker)
GL_ALPHA12_EXT=_C('GL_ALPHA12_EXT',0x803D)
GL_ALPHA16_EXT=_C('GL_ALPHA16_EXT',0x803E)
GL_ALPHA4_EXT=_C('GL_ALPHA4_EXT',0x803B)
GL_ALPHA8_EXT=_C('GL_ALPHA8_EXT',0x803C)
GL_INTENSITY12_EXT=_C('GL_INTENSITY12_EXT',0x804C)
GL_INTENSITY16_EXT=_C('GL_INTENSITY16_EXT',0x804D)
GL_INTENSITY4_EXT=_C('GL_INTENSITY4_EXT',0x804A)
GL_INTENSITY8_EXT=_C('GL_INTENSITY8_EXT',0x804B)
GL_INTENSITY_EXT=_C('GL_INTENSITY_EXT',0x8049)
GL_LUMINANCE12_ALPHA12_EXT=_C('GL_LUMINANCE12_ALPHA12_EXT',0x8047)
GL_LUMINANCE12_ALPHA4_EXT=_C('GL_LUMINANCE12_ALPHA4_EXT',0x8046)
GL_LUMINANCE12_EXT=_C('GL_LUMINANCE12_EXT',0x8041)
GL_LUMINANCE16_ALPHA16_EXT=_C('GL_LUMINANCE16_ALPHA16_EXT',0x8048)
GL_LUMINANCE16_EXT=_C('GL_LUMINANCE16_EXT',0x8042)
GL_LUMINANCE4_ALPHA4_EXT=_C('GL_LUMINANCE4_ALPHA4_EXT',0x8043)
GL_LUMINANCE4_EXT=_C('GL_LUMINANCE4_EXT',0x803F)
GL_LUMINANCE6_ALPHA2_EXT=_C('GL_LUMINANCE6_ALPHA2_EXT',0x8044)
GL_LUMINANCE8_ALPHA8_EXT=_C('GL_LUMINANCE8_ALPHA8_EXT',0x8045)
GL_LUMINANCE8_EXT=_C('GL_LUMINANCE8_EXT',0x8040)
GL_PROXY_TEXTURE_1D_EXT=_C('GL_PROXY_TEXTURE_1D_EXT',0x8063)
GL_PROXY_TEXTURE_2D_EXT=_C('GL_PROXY_TEXTURE_2D_EXT',0x8064)
GL_REPLACE_EXT=_C('GL_REPLACE_EXT',0x8062)
GL_RGB10_A2_EXT=_C('GL_RGB10_A2_EXT',0x8059)
GL_RGB10_EXT=_C('GL_RGB10_EXT',0x8052)
GL_RGB12_EXT=_C('GL_RGB12_EXT',0x8053)
GL_RGB16_EXT=_C('GL_RGB16_EXT',0x8054)
GL_RGB2_EXT=_C('GL_RGB2_EXT',0x804E)
GL_RGB4_EXT=_C('GL_RGB4_EXT',0x804F)
GL_RGB5_A1_EXT=_C('GL_RGB5_A1_EXT',0x8057)
GL_RGB5_EXT=_C('GL_RGB5_EXT',0x8050)
GL_RGB8_EXT=_C('GL_RGB8_EXT',0x8051)
GL_RGBA12_EXT=_C('GL_RGBA12_EXT',0x805A)
GL_RGBA16_EXT=_C('GL_RGBA16_EXT',0x805B)
GL_RGBA2_EXT=_C('GL_RGBA2_EXT',0x8055)
GL_RGBA4_EXT=_C('GL_RGBA4_EXT',0x8056)
GL_RGBA8_EXT=_C('GL_RGBA8_EXT',0x8058)
GL_TEXTURE_ALPHA_SIZE_EXT=_C('GL_TEXTURE_ALPHA_SIZE_EXT',0x805F)
GL_TEXTURE_BLUE_SIZE_EXT=_C('GL_TEXTURE_BLUE_SIZE_EXT',0x805E)
GL_TEXTURE_GREEN_SIZE_EXT=_C('GL_TEXTURE_GREEN_SIZE_EXT',0x805D)
GL_TEXTURE_INTENSITY_SIZE_EXT=_C('GL_TEXTURE_INTENSITY_SIZE_EXT',0x8061)
GL_TEXTURE_LUMINANCE_SIZE_EXT=_C('GL_TEXTURE_LUMINANCE_SIZE_EXT',0x8060)
GL_TEXTURE_RED_SIZE_EXT=_C('GL_TEXTURE_RED_SIZE_EXT',0x805C)
GL_TEXTURE_TOO_LARGE_EXT=_C('GL_TEXTURE_TOO_LARGE_EXT',0x8065)

