'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_OES_mapbuffer'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_OES_mapbuffer',error_checker=_errors._error_checker)
GL_BUFFER_ACCESS_OES=_C('GL_BUFFER_ACCESS_OES',0x88BB)
GL_BUFFER_MAPPED_OES=_C('GL_BUFFER_MAPPED_OES',0x88BC)
GL_BUFFER_MAP_POINTER_OES=_C('GL_BUFFER_MAP_POINTER_OES',0x88BD)
GL_WRITE_ONLY_OES=_C('GL_WRITE_ONLY_OES',0x88B9)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLvoidpArray)
def glGetBufferPointervOES(target,pname,params):pass
@_f
@_p.types(ctypes.c_void_p,_cs.GLenum,_cs.GLenum)
def glMapBufferOES(target,access):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLenum)
def glUnmapBufferOES(target):pass
