'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_NV_blend_equation_advanced'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_NV_blend_equation_advanced',error_checker=_errors._error_checker)
GL_BLEND_OVERLAP_NV=_C('GL_BLEND_OVERLAP_NV',0x9281)
GL_BLEND_PREMULTIPLIED_SRC_NV=_C('GL_BLEND_PREMULTIPLIED_SRC_NV',0x9280)
GL_BLUE_NV=_C('GL_BLUE_NV',0x1905)
GL_COLORBURN_NV=_C('GL_COLORBURN_NV',0x929A)
GL_COLORDODGE_NV=_C('GL_COLORDODGE_NV',0x9299)
GL_CONJOINT_NV=_C('GL_CONJOINT_NV',0x9284)
GL_CONTRAST_NV=_C('GL_CONTRAST_NV',0x92A1)
GL_DARKEN_NV=_C('GL_DARKEN_NV',0x9297)
GL_DIFFERENCE_NV=_C('GL_DIFFERENCE_NV',0x929E)
GL_DISJOINT_NV=_C('GL_DISJOINT_NV',0x9283)
GL_DST_ATOP_NV=_C('GL_DST_ATOP_NV',0x928F)
GL_DST_IN_NV=_C('GL_DST_IN_NV',0x928B)
GL_DST_NV=_C('GL_DST_NV',0x9287)
GL_DST_OUT_NV=_C('GL_DST_OUT_NV',0x928D)
GL_DST_OVER_NV=_C('GL_DST_OVER_NV',0x9289)
GL_EXCLUSION_NV=_C('GL_EXCLUSION_NV',0x92A0)
GL_GREEN_NV=_C('GL_GREEN_NV',0x1904)
GL_HARDLIGHT_NV=_C('GL_HARDLIGHT_NV',0x929B)
GL_HARDMIX_NV=_C('GL_HARDMIX_NV',0x92A9)
GL_HSL_COLOR_NV=_C('GL_HSL_COLOR_NV',0x92AF)
GL_HSL_HUE_NV=_C('GL_HSL_HUE_NV',0x92AD)
GL_HSL_LUMINOSITY_NV=_C('GL_HSL_LUMINOSITY_NV',0x92B0)
GL_HSL_SATURATION_NV=_C('GL_HSL_SATURATION_NV',0x92AE)
GL_INVERT=_C('GL_INVERT',0x150A)
GL_INVERT_OVG_NV=_C('GL_INVERT_OVG_NV',0x92B4)
GL_INVERT_RGB_NV=_C('GL_INVERT_RGB_NV',0x92A3)
GL_LIGHTEN_NV=_C('GL_LIGHTEN_NV',0x9298)
GL_LINEARBURN_NV=_C('GL_LINEARBURN_NV',0x92A5)
GL_LINEARDODGE_NV=_C('GL_LINEARDODGE_NV',0x92A4)
GL_LINEARLIGHT_NV=_C('GL_LINEARLIGHT_NV',0x92A7)
GL_MINUS_CLAMPED_NV=_C('GL_MINUS_CLAMPED_NV',0x92B3)
GL_MINUS_NV=_C('GL_MINUS_NV',0x929F)
GL_MULTIPLY_NV=_C('GL_MULTIPLY_NV',0x9294)
GL_OVERLAY_NV=_C('GL_OVERLAY_NV',0x9296)
GL_PINLIGHT_NV=_C('GL_PINLIGHT_NV',0x92A8)
GL_PLUS_CLAMPED_ALPHA_NV=_C('GL_PLUS_CLAMPED_ALPHA_NV',0x92B2)
GL_PLUS_CLAMPED_NV=_C('GL_PLUS_CLAMPED_NV',0x92B1)
GL_PLUS_DARKER_NV=_C('GL_PLUS_DARKER_NV',0x9292)
GL_PLUS_NV=_C('GL_PLUS_NV',0x9291)
GL_RED_NV=_C('GL_RED_NV',0x1903)
GL_SCREEN_NV=_C('GL_SCREEN_NV',0x9295)
GL_SOFTLIGHT_NV=_C('GL_SOFTLIGHT_NV',0x929C)
GL_SRC_ATOP_NV=_C('GL_SRC_ATOP_NV',0x928E)
GL_SRC_IN_NV=_C('GL_SRC_IN_NV',0x928A)
GL_SRC_NV=_C('GL_SRC_NV',0x9286)
GL_SRC_OUT_NV=_C('GL_SRC_OUT_NV',0x928C)
GL_SRC_OVER_NV=_C('GL_SRC_OVER_NV',0x9288)
GL_UNCORRELATED_NV=_C('GL_UNCORRELATED_NV',0x9282)
GL_VIVIDLIGHT_NV=_C('GL_VIVIDLIGHT_NV',0x92A6)
GL_XOR_NV=_C('GL_XOR_NV',0x1506)
GL_ZERO=_C('GL_ZERO',0)
@_f
@_p.types(None,)
def glBlendBarrierNV():pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glBlendParameteriNV(pname,value):pass
