'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_sparse_buffer'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_sparse_buffer',error_checker=_errors._error_checker)
GL_SPARSE_BUFFER_PAGE_SIZE_ARB=_C('GL_SPARSE_BUFFER_PAGE_SIZE_ARB',0x82F8)
GL_SPARSE_STORAGE_BIT_ARB=_C('GL_SPARSE_STORAGE_BIT_ARB',0x0400)
@_f
@_p.types(None,_cs.GLenum,_cs.GLintptr,_cs.GLsizeiptr,_cs.GLboolean)
def glBufferPageCommitmentARB(target,offset,size,commit):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLintptr,_cs.GLsizeiptr,_cs.GLboolean)
def glNamedBufferPageCommitmentARB(buffer,offset,size,commit):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLintptr,_cs.GLsizeiptr,_cs.GLboolean)
def glNamedBufferPageCommitmentEXT(buffer,offset,size,commit):pass
