'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_AMD_sparse_texture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_AMD_sparse_texture',error_checker=_errors._error_checker)
GL_MAX_SPARSE_3D_TEXTURE_SIZE_AMD=_C('GL_MAX_SPARSE_3D_TEXTURE_SIZE_AMD',0x9199)
GL_MAX_SPARSE_ARRAY_TEXTURE_LAYERS=_C('GL_MAX_SPARSE_ARRAY_TEXTURE_LAYERS',0x919A)
GL_MAX_SPARSE_TEXTURE_SIZE_AMD=_C('GL_MAX_SPARSE_TEXTURE_SIZE_AMD',0x9198)
GL_MIN_LOD_WARNING_AMD=_C('GL_MIN_LOD_WARNING_AMD',0x919C)
GL_MIN_SPARSE_LEVEL_AMD=_C('GL_MIN_SPARSE_LEVEL_AMD',0x919B)
GL_TEXTURE_STORAGE_SPARSE_BIT_AMD=_C('GL_TEXTURE_STORAGE_SPARSE_BIT_AMD',0x00000001)
GL_VIRTUAL_PAGE_SIZE_X_AMD=_C('GL_VIRTUAL_PAGE_SIZE_X_AMD',0x9195)
GL_VIRTUAL_PAGE_SIZE_Y_AMD=_C('GL_VIRTUAL_PAGE_SIZE_Y_AMD',0x9196)
GL_VIRTUAL_PAGE_SIZE_Z_AMD=_C('GL_VIRTUAL_PAGE_SIZE_Z_AMD',0x9197)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLbitfield)
def glTexStorageSparseAMD(target,internalFormat,width,height,depth,layers,flags):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLbitfield)
def glTextureStorageSparseAMD(texture,target,internalFormat,width,height,depth,layers,flags):pass
