'''OpenGL extension SGI.texture_color_table

This module customises the behaviour of the 
OpenGL.raw.GL.SGI.texture_color_table to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds a color lookup table to the texture mechanism.
	The table is applied to the filtered result of a texture lookup,
	before that result is used in the texture environment equations.
	
	The definition and application of the texture color table are
	similar to those of the color tables defined in SGI_color_table,
	though it is not necessary for that extension to be implemented.
	
	Texture color tables can be used to expand luminance or intensity
	textures to full RGBA, and also to linearize the results of color
	space conversions implemented by multidimensional texture table
	lookup.
	
	This specification has been updated to define its interaction with
	multitexture.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGI/texture_color_table.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGI.texture_color_table import *
from OpenGL.raw.GL.SGI.texture_color_table import _EXTENSION_NAME

def glInitTextureColorTableSGI():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION